%define mainver %(echo %{version} | sed -e 's/\\([0-9]*\\.[0-9]*\\)\\.[0-9]*/\\1/')

%define module  Twisted

Name:           python-twisted
Version:        19.2.1
%global subrel	2
Release:        %mkrel 1
Summary:        Event-based framework for internet applications
License:        MIT
Group:          Development/Python
URL:            http://www.twistedmatrix.com/
Source0:        https://files.pythonhosted.org/packages/source/T/%{module}/%{module}-%{version}.tar.bz2
# From upstream PR to fix CVE-2019-12855
# https://github.com/twisted/twisted/pull/1147
Patch1:		https://github.com/twisted/twisted/pull/1147.patch
# CVE-2020-10108
# CVE-2020-10109
Patch2:         https://github.com/twisted/twisted/commit/d2f6dd9b3766509f40c980aac67ca8475da67c6f.patch#/0001-Refactor-to-reduce-duplication.patch
Patch3:         https://github.com/twisted/twisted/commit/4a7d22e490bb8ff836892cc99a1f54b85ccb0281.patch#/0001-Fix-several-request-smuggling-attacks.patch
	
 
BuildRequires:  pkgconfig(python2)
BuildRequires:  python2dist(incremental)
BuildRequires:  python2dist(setuptools)
BuildRequires:  python2dist(zope.interface)

BuildRequires:  pkgconfig(python3)
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(zope.interface)
BuildRequires:  python3dist(incremental)

%description
Twisted is a framework, written in Python, for writing networked
applications. It includes implementations of a number of commonly used
network services such as a web server, an IRC chat server, a mail
server, a relational database interface and an object broker. Developers
can build applications using all of these services as well as custom
services that they write themselves. Twisted also includes a user
authentication system that controls access to services and provides
services with user context information to implement their own security
models.

%package -n python2-twisted
Summary:        Python2 event-based framework for internet applications
Group:          Development/Python
Requires:       python2dist(pycrypto)
Requires:       python2dist(pyopenssl)
Requires:       python2dist(zope.interface)
Requires:       python2dist(pygobject)
Requires:       python2dist(service-identity)
# python-twisted-core
Requires:       python2dist(pyserial)
# python-twisted-conch
Requires:       python2dist(pyasn1)

Obsoletes:      python-twisted < 17.5.0-3
Provides:       python-twisted = %{version}-%{release}
# Bring all provided resources back into the main package namespace.
Obsoletes:      python-twisted-conch < 15.2.1-2
Provides:       python-twisted-conch = %{version}-%{release}
Obsoletes:      python-twisted-core < 15.2.1-2
Provides:       python-twisted-core = %{version}-%{release}
Obsoletes:      python-twisted-lore < 15.2.1-2
Provides:       python-twisted-lore = %{version}-%{release}
Obsoletes:      python-twisted-mail < 15.2.1-2
Provides:       python-twisted-mail = %{version}-%{release}
Obsoletes:      python-twisted-names < 15.2.1-2
Provides:       python-twisted-names = %{version}-%{release}
Obsoletes:      python-twisted-news < 15.2.1-2
Provides:       python-twisted-news = %{version}-%{release}
Obsoletes:      python-twisted-pair < 15.2.1-2
Provides:       python-twisted-pair = %{version}-%{release}
Obsoletes:      python-twisted-runner < 15.2.1-2
Provides:       python-twisted-runner = %{version}-%{release}
Obsoletes:      python-twisted-web < 15.2.1-2
Provides:       python-twisted-web = %{version}-%{release}
Obsoletes:      python-twisted-words < 15.2.1-2
Provides:       python-twisted-words = %{version}-%{release}

%description -n python2-twisted
Twisted is a framework, written in Python2, for writing networked
applications. It includes implementations of a number of commonly used
network services such as a web server, an IRC chat server, a mail
server, a relational database interface and an object broker. Developers
can build applications using all of these services as well as custom
services that they write themselves. Twisted also includes a user
authentication system that controls access to services and provides
services with user context information to implement their own security
models.

%package -n python3-twisted
Summary:        Python3 event-based framework for internet applications
Group:          Development/Python
Requires:       python3dist(pycrypto)
Requires:       python3dist(pyopenssl)
Requires:       python3dist(zope.interface)
Requires:       python3dist(pygobject)
Requires:       python3dist(pyserial)
Requires:       python3dist(pyasn1)
Requires:       python3dist(service-identity)

%description -n python3-twisted
Twisted is a framework, written in Python3, for writing networked
applications. It includes implementations of a number of commonly used
network services such as a web server, an IRC chat server, a mail
server, a relational database interface and an object broker. Developers
can build applications using all of these services as well as custom
services that they write themselves. Twisted also includes a user
authentication system that controls access to services and provides
services with user context information to implement their own security
models.

%prep
%autosetup -n %{module}-%{version} -p1

%build
%py2_build
%py3_build

%install
%py3_install

# twisted in python 3 supports only few command line tools for now.
# Let's rename the tools the other way round after the python 3 version supports all.
for name in cftp ckeygen conch pyhtmlizer tkconch trial twist twistd; do
  mv "%{buildroot}%{_bindir}/$name"{,3}
done

%py2_install

# no need for c and h source code
find %{buildroot}%{python2_sitearch}/twisted -name '*.c' -delete
find %{buildroot}%{python2_sitearch}/twisted -name '*.h' -delete
find %{buildroot}%{python3_sitearch}/twisted -name '*.c' -delete
find %{buildroot}%{python3_sitearch}/twisted -name '*.h' -delete

# pem-certificate
find %{buildroot}%{python2_sitearch}/twisted -name '*.pem' -delete
find %{buildroot}%{python3_sitearch}/twisted -name '*.pem' -delete

# non-executable-script
chmod +x %{buildroot}%{python2_sitearch}/twisted/mail/test/pop3testserver.py
chmod +x %{buildroot}%{python2_sitearch}/twisted/trial/test/scripttest.py
chmod +x %{buildroot}%{python3_sitearch}/twisted/trial/test/scripttest.py

# no-manual-page-for-binary
mkdir -p %{buildroot}%{_mandir}/man1/
for s in conch core mail; do
  cp -pr docs/$s/man/*.1 %{buildroot}%{_mandir}/man1/
done

%files -n python2-twisted
%doc CONTRIBUTING NEWS.rst README.rst docs/*
%license LICENSE
%{_bindir}/cftp
%{_bindir}/ckeygen
%{_bindir}/conch
%{_bindir}/mailmail
%{_bindir}/pyhtmlizer
%{_bindir}/tkconch
%{_bindir}/trial
%{_bindir}/twist
%{_bindir}/twistd
%{python2_sitearch}/twisted/
%{python2_sitearch}/%{module}-%{version}-py%{python2_version}.egg-info/
%{_mandir}/man1/*.1.*


%files -n python3-twisted
%doc CONTRIBUTING NEWS.rst README.rst docs/*
%license LICENSE
%{_bindir}/cftp3
%{_bindir}/ckeygen3
%{_bindir}/conch3
%{_bindir}/pyhtmlizer3
%{_bindir}/tkconch3
%{_bindir}/trial3
%{_bindir}/twist3
%{_bindir}/twistd3
%{python3_sitearch}/twisted/
%{python3_sitearch}/%{module}-%{version}-py%{python3_version}.egg-info/
%{_mandir}/man1/*.1.*


%changelog
* Sat Nov 14 2020 philippem <philippem> 19.2.1-1.2.mga7
+ Revision: 1645848
- security issues CVE-2020-10108 and CVE-2020-10109 mga#26355

* Wed Nov 27 2019 wally <wally> 19.2.1-1.1.mga7
+ Revision: 1463215
- add patches from upstream pull request to fix CVE-2019-12855 (mga#25752)

* Tue Nov 26 2019 wally <wally> 19.2.1-1.mga7
+ Revision: 1462958
- new version 19.2.1 to fix CVE-2019-12387 (mga#25752)

* Sat Apr 20 2019 wally <wally> 19.2.0-1.mga7
+ Revision: 1393950
- new version 19.2.0

* Wed Jan 09 2019 kekepower <kekepower> 18.9.0-1.mga7
+ Revision: 1353490
- Update to version 18.9.0

* Mon Jan 07 2019 wally <wally> 18.7.0-2.mga7
+ Revision: 1350919
- require service-identity

* Sat Jan 05 2019 wally <wally> 18.7.0-1.mga7
+ Revision: 1349527
- new version 18.7.0
- add patch from Fedora to add python3.7 support

* Sun Sep 23 2018 umeabot <umeabot> 17.5.0-5.mga7
+ Revision: 1300614
- Mageia 7 Mass Rebuild

* Tue Feb 20 2018 daviddavid <daviddavid> 17.5.0-4.mga7
+ Revision: 1203444
- rename python-twisted to python2-twisted

* Wed Oct 04 2017 tv <tv> 17.5.0-3.mga7
+ Revision: 1168597
- BR python-incremental thus fixing build

* Sat Aug 05 2017 pterjan <pterjan> 17.5.0-2.mga7
+ Revision: 1135671
- Rebuild for python 3.6

* Sat Jul 29 2017 daviddavid <daviddavid> 17.5.0-1.mga7
+ Revision: 1132262
- new version: 17.5.0
- python3-twisted subpackage is no more a noarch package

* Sat Aug 20 2016 philippem <philippem> 16.3.2-1.mga6
+ Revision: 1047146
- update to 16.3.2

* Thu May 19 2016 philippem <philippem> 16.2.0-1.mga6
+ Revision: 1016881
- update to 16.2.0

* Mon Apr 25 2016 philippem <philippem> 16.1.1-1.mga6
+ Revision: 1006100
- update to 16.1.1

* Mon Apr 04 2016 philippem <philippem> 16.1.0-1.mga6
+ Revision: 998390
- set python3 as noarch
- fix some files for Python3
- update to 16.1.0 - add Python3 version

* Wed Mar 16 2016 philippem <philippem> 16.0.0-1.mga6
+ Revision: 992150
- update to 16.0.0
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Mon Nov 30 2015 daviddavid <daviddavid> 15.5.0-1.mga6
+ Revision: 907276
- new version: 15.5.0

* Wed Oct 07 2015 daviddavid <daviddavid> 15.4.0-2.mga6
+ Revision: 886879
- fix python2 macro

* Fri Sep 18 2015 daviddavid <daviddavid> 15.4.0-1.mga6
+ Revision: 880293
- new version: 15.4.0
- ship Twisted as a fully featured package without subpackages on the advice
- use new python macros
- introduce license macro

* Mon Jun 22 2015 daviddavid <daviddavid> 15.2.1-1.mga6
+ Revision: 839072
- new version: 15.2.1

* Wed Oct 15 2014 umeabot <umeabot> 14.0.0-4.mga5
+ Revision: 742469
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 14.0.0-3.mga5
+ Revision: 729889
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 14.0.0-2.mga5
+ Revision: 688387
- Mageia 5 Mass Rebuild

* Sat Jun 07 2014 daviddavid <daviddavid> 14.0.0-1.mga5
+ Revision: 634568
- add new required package on python-twisted-pair
+ philippem <philippem>
- update to 14.0.0, remove pythonegg(3) provides

* Mon Mar 31 2014 kharec <kharec> 13.2.0-1.mga5
+ Revision: 610801
- version 13.2.0

* Tue Oct 22 2013 neoclust <neoclust> 13.1.0-4.mga4
+ Revision: 546302
- Add missing provides

* Tue Oct 22 2013 umeabot <umeabot> 13.1.0-3.mga4
+ Revision: 544363
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 13.1.0-2.mga4
+ Revision: 499580
- Rebuild to add different pythonegg provides for python 2 and 3

* Sat Oct 05 2013 philippem <philippem> 13.1.0-1.mga4
+ Revision: 491851
- Update to 13.1.0

* Sun Jan 13 2013 umeabot <umeabot> 12.2.0-2.mga3
+ Revision: 379586
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Sep 20 2012 philippem <philippem> 12.2.0-1.mga3
+ Revision: 296404
- Update to 12.2.0
+ guillomovitch <guillomovitch>
- spec cleanup
- rename distribution-specific documentation file to README.mga

* Wed Nov 23 2011 philippem <philippem> 11.1.0-1.mga2
+ Revision: 171272
- Update to 11.1.0

* Sun Jun 19 2011 kharec <kharec> 11.0.0-1.mga2
+ Revision: 110004
- new version 11.0.0

* Tue Mar 29 2011 ahmad <ahmad> 10.2.0-2.mga1
+ Revision: 78952
- add the pythonegg provides manually as this is a meta package, so the rpm
  pythonegg auto-provides scripts won't work here

* Mon Feb 21 2011 ahmad <ahmad> 10.2.0-1.mga1
+ Revision: 55818
- update to 10.2.0

* Wed Jan 19 2011 erwan <erwan> 10.1.0-2.mga1
+ Revision: 24864
- imported package python-twisted

